==> openshift-model-6.9.0-sources.jar: io/fabric8/openshift/api/model/BuildVolumeSourceFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.model.SecretVolumeSource;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.CSIVolumeSource;
import io.fabric8.kubernetes.api.model.ConfigMapVolumeSource;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class BuildVolumeSourceFluent<A extends BuildVolumeSourceFluent<A>> extends BaseFluent<A>{
  public BuildVolumeSourceFluent() {
  }
  
  public BuildVolumeSourceFluent(BuildVolumeSource instance) {
    this.copyInstance(instance);
  }
  private ConfigMapVolumeSource configMap;
  private CSIVolumeSource csi;
  private SecretVolumeSource secret;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(BuildVolumeSource instance) {
    instance = (instance != null ? instance : new BuildVolumeSource());
  
    if (instance != null) {
        this.withConfigMap(instance.getConfigMap());
        this.withCsi(instance.getCsi());
        this.withSecret(instance.getSecret());
        this.withType(instance.getType());
        this.withConfigMap(instance.getConfigMap());
        this.withCsi(instance.getCsi());
        this.withSecret(instance.getSecret());
        this.withType(instance.getType());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public ConfigMapVolumeSource getConfigMap() {
    return this.configMap;
  }
  
  public A withConfigMap(ConfigMapVolumeSource configMap) {
    this.configMap=configMap; return (A) this;
  }
  
  public boolean hasConfigMap() {
    return this.configMap != null;
  }
  
  public CSIVolumeSource getCsi() {
    return this.csi;
  }
  
  public A withCsi(CSIVolumeSource csi) {
    this.csi=csi; return (A) this;
  }
  
  public boolean hasCsi() {
    return this.csi != null;
  }
  
  public SecretVolumeSource getSecret() {
    return this.secret;
  }
  
  public A withSecret(SecretVolumeSource secret) {
    this.secret=secret; return (A) this;
  }
  
  public boolean hasSecret() {
    return this.secret != null;
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BuildVolumeSourceFluent that = (BuildVolumeSourceFluent) o;
    if (!java.util.Objects.equals(configMap, that.configMap)) return false;
  
    if (!java.util.Objects.equals(csi, that.csi)) return false;
  
    if (!java.util.Objects.equals(secret, that.secret)) return false;
  
    if (!java.util.Objects.equals(type, that.type)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(configMap,  csi,  secret,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (configMap != null) { sb.append("configMap:"); sb.append(configMap + ","); }
    if (csi != null) { sb.append("csi:"); sb.append(csi + ","); }
    if (secret != null) { sb.append("secret:"); sb.append(secret + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-6.9.1-sources.jar: io/fabric8/openshift/api/model/BuildVolumeSourceFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.model.SecretVolumeSource;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.CSIVolumeSource;
import io.fabric8.kubernetes.api.model.ConfigMapVolumeSource;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class BuildVolumeSourceFluent<A extends BuildVolumeSourceFluent<A>> extends BaseFluent<A>{
  public BuildVolumeSourceFluent() {
  }
  
  public BuildVolumeSourceFluent(BuildVolumeSource instance) {
    this.copyInstance(instance);
  }
  private ConfigMapVolumeSource configMap;
  private CSIVolumeSource csi;
  private SecretVolumeSource secret;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(BuildVolumeSource instance) {
    instance = (instance != null ? instance : new BuildVolumeSource());
    if (instance != null) {
          this.withConfigMap(instance.getConfigMap());
          this.withCsi(instance.getCsi());
          this.withSecret(instance.getSecret());
          this.withType(instance.getType());
          this.withConfigMap(instance.getConfigMap());
          this.withCsi(instance.getCsi());
          this.withSecret(instance.getSecret());
          this.withType(instance.getType());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public ConfigMapVolumeSource getConfigMap() {
    return this.configMap;
  }
  
  public A withConfigMap(ConfigMapVolumeSource configMap) {
    this.configMap = configMap;
    return (A) this;
  }
  
  public boolean hasConfigMap() {
    return this.configMap != null;
  }
  
  public CSIVolumeSource getCsi() {
    return this.csi;
  }
  
  public A withCsi(CSIVolumeSource csi) {
    this.csi = csi;
    return (A) this;
  }
  
  public boolean hasCsi() {
    return this.csi != null;
  }
  
  public SecretVolumeSource getSecret() {
    return this.secret;
  }
  
  public A withSecret(SecretVolumeSource secret) {
    this.secret = secret;
    return (A) this;
  }
  
  public boolean hasSecret() {
    return this.secret != null;
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type = type;
    return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BuildVolumeSourceFluent that = (BuildVolumeSourceFluent) o;
    if (!java.util.Objects.equals(configMap, that.configMap)) return false;
    if (!java.util.Objects.equals(csi, that.csi)) return false;
    if (!java.util.Objects.equals(secret, that.secret)) return false;
    if (!java.util.Objects.equals(type, that.type)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(configMap,  csi,  secret,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (configMap != null) { sb.append("configMap:"); sb.append(configMap + ","); }
    if (csi != null) { sb.append("csi:"); sb.append(csi + ","); }
    if (secret != null) { sb.append("secret:"); sb.append(secret + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
